@@ -1,9 +1,8 @@
-
 import abc
 import logging
 import struct
 
-from typing import Any, Dict, List
+from typing import Any
 
 from qtoggleserver.lib import ble
 
@@ -13,9 +12,6 @@ from .inverter import MPPSolarInverter
 from .typing import Property
 
 
-logger = logging.getLogger(__name__)
-
-
 class BluetoothPort(ble.BLEPort, metaclass=abc.ABCMeta):
     READ_INTERVAL_MAX = 86400
     READ_INTERVAL_STEP = 1
@@ -39,7 +35,7 @@ class BluetoothMPPSolarInverter(MPPSolarInverter, ble.BLEPeripheral):
     STATUS2_HANDLE = 0x0020
     PV1_STATUS_HANDLE = 0x0042
 
-    logger = logger
+    logger = logging.getLogger(__name__)
 
     async def read_properties(self) -> None:
         data = await self.read(self.STATUS1_HANDLE)
@@ -86,7 +82,7 @@ class BluetoothMPPSolarInverter(MPPSolarInverter, ble.BLEPeripheral):
         self._properties['pv_voltage'] = pv_voltage / 10
         self._properties['pv_power'] = pv_power
 
-    async def make_port_args(self) -> List[Dict[str, Any]]:
+    async def make_port_args(self) -> list[dict[str, Any]]:
         return [
             {
                 'driver': NumberPort,
