@@ -1,6 +1,3 @@
-
-from typing import List, Type
-
 from .base import Command
 from .mchgc import MCHGC
 from .mnchgc import MNCHGC_Parallel, MNCHGC_Single
@@ -19,7 +16,7 @@ from .qmuchgcr import QMUCHGCR
 from .qmod import QMOD
 from .qpigs import QPIGS, QPIGS_LV, QPIGS_GKMK, QPIGS_MAX
 from .qpigs2 import QPIGS2, QPIGS2_MAX
-from .qpiri import QPIRI, QPIRI_GKMK, QPIRI_MAX
+from .qpiri import QPIRI, QPIRI_GK, QPIRI_MAX, QPIRI_MK
 
 
 COMMANDS_BY_MODEL = {
@@ -38,7 +35,7 @@ COMMANDS_BY_MODEL = {
         QMUCHGCR,
         QMOD,
         QPIGS_GKMK,
-        QPIRI_GKMK,
+        QPIRI_GK,
     ],
     'LV': [
         MNCHGC_Single,
@@ -88,10 +85,10 @@ COMMANDS_BY_MODEL = {
         QMCHGCR,
         QMOD,
         QPIGS_GKMK,
-        QPIRI_GKMK,
+        QPIRI_MK,
     ],
 }
 
 
-def get_command_classes(model: str) -> List[Type[Command]]:
+def get_command_classes(model: str) -> list[type[Command]]:
     return COMMANDS_BY_MODEL.get(model, [])
