@@ -1,8 +1,7 @@
-
 import ctypes
 import re
 
-from typing import Optional, Tuple
+from typing import Optional
 
 from ..exceptions import MPPSolarException
 from ..typing import Properties, PropertyDefinitions
@@ -35,7 +34,7 @@ class Command:
         'str': str
     }
 
-    _response_regex: Optional[Tuple[Optional[re.Pattern], re.Pattern]] = None
+    _response_regex: Optional[tuple[Optional[re.Pattern], re.Pattern]] = None
     _request_property_definitions: Optional[PropertyDefinitions] = None
     _response_property_definitions: Optional[PropertyDefinitions] = None
 
@@ -57,14 +56,14 @@ class Command:
         if not response.endswith(b'\r'):
             raise ResponseError(f'Unexpected response end: {response}')
 
-        response = response[:-1]  # Get rid of terminal '\r'
+        response = response[:-1]  # get rid of terminal '\r'
 
         crc = response[-2:]
         response = response[:-2].decode()
         if self.compute_crc(response) != crc:
-            raise ResponseError(f'Wrong CRC: {response}')
+            raise ResponseError(f'Wrong CRC: {response} {repr(crc)[2:-1]}')
 
-        response = response[1:]  # Get rid of start byte '('
+        response = response[1:]  # get rid of start byte '('
 
         split_pat, values_pat = self.get_response_regex()
         if split_pat:
@@ -88,8 +87,10 @@ class Command:
 
         # Add virtual properties
         for name, details in self.VIRTUAL_PROPERTIES.items():
+            if not details:
+                continue  # property disabled in command subclass
             if name in parsed_dict:
-                continue  # Property already present
+                continue  # property already present
 
             parsed_dict[name] = details['value'](parsed_dict)
 
@@ -117,7 +118,7 @@ class Command:
                 response_fmt = response_fmt[:-3]
 
             matches = re.findall(r'{([^:]+):([dfbs])}', response_fmt)
-            matches += [(name, details['type']) for name, details in cls.VIRTUAL_PROPERTIES.items()]
+            matches += [(name, details['type']) for name, details in cls.VIRTUAL_PROPERTIES.items() if details]
             type_mapping = {
                 'd': 'int',
                 'f': 'float',
@@ -149,7 +150,7 @@ class Command:
         return False
 
     @classmethod
-    def get_response_regex(cls) -> Tuple[Optional[re.Pattern], re.Pattern]:
+    def get_response_regex(cls) -> tuple[Optional[re.Pattern], re.Pattern]:
         if cls._response_regex is None:
             pat = cls.RESPONSE_FMT
             is_list = False
