@@ -1,4 +1,3 @@
-
 from .base import Command
 
 
@@ -64,28 +63,12 @@ class QPIGS(Command):
         'battery_discharging_current': 'Battery Discharging Current',
         'battery_state_of_charge': 'Battery State Of Charge',
         'battery_voltage': 'Battery Voltage',
-        'battery_voltage_offset_fans': 'Battery Voltage Offset Fans',
         'bus_voltage': 'Bus Voltage',
-        'eeprom_version': 'EEPROM Version',
         'grid_frequency': 'Grid Frequency',
         'grid_voltage': 'Grid Voltage',
         'has_load': 'Has Load',
-        'has_sbu_priority': 'Has SBU Priority',
         'heat_sink_temperature': 'Heat Sink Temperature',
         'is_ac_output_from_grid_or_pv': 'AC Output From Grid/PV',
-        'is_battery_charging': 'Battery Charging',
-        'is_battery_charging_from_grid': 'Battery Charging From Grid',
-        'is_battery_charging_from_scc': 'Battery Charging From SCC',
-        'is_battery_float_charging': 'Battery Float-charging',
-        'is_battery_low': 'Battery Low',
-        'is_battery_present': 'Battery Present',
-        'is_battery_voltage_too_steady_while_charging': 'Battery Voltage Too Steady While Charging',
-        'is_configuration_status_changed': 'Configuration Status Changed',
-        'is_dustproof_installed': 'Dustproof Installed',
-        'is_grid_present': 'Grid Present',
-        'is_scc_active': 'SCC Active',
-        'is_scc_firmware_updated': 'SCC Firmware Updated',
-        'is_turned_on': 'Turned On',
         'pv_charging_power': 'PV Charging Power',
         'pv_current': 'PV Current',
         'pv_power': 'PV Power',
@@ -98,13 +81,6 @@ class QPIGS(Command):
             'value': lambda properties: properties.get('pv_current', 0) * properties.get('pv_voltage', 0),
             'type': 'float'
         },
-        'is_battery_charging': {
-            'value': lambda properties: (
-                properties.get('is_battery_charging_from_grid', False) or
-                properties.get('is_battery_charging_from_scc', False)
-            ),
-            'type': 'bool'
-        },
     }
 
 
@@ -191,8 +167,8 @@ class QPIGS_MAX(QPIGS):
         '{battery_charging_current:f} '
         '{battery_state_of_charge:f} '
         '{heat_sink_temperature:f} '
-        '{pv_current:f} '
-        '{pv_voltage:f} '
+        '{pv1_current:f} '
+        '{pv1_voltage:f} '
         '{scc_voltage:f} '
         '{battery_discharging_current:f} '
         '{has_sbu_priority:b}'
@@ -205,8 +181,12 @@ class QPIGS_MAX(QPIGS):
         '{is_battery_charging_from_grid:b} '
         '{battery_voltage_offset_fans:d} '
         '{eeprom_version:d} '
-        '{pv_charging_power:d} '
+        '{pv1_power:d} '
         '{is_battery_float_charging:b}'
         '{is_turned_on:b}'
         '{is_dustproof_installed:b}'
     )
+
+    VIRTUAL_PROPERTIES = {
+        'pv_power': None,
+    }
