@@ -1,4 +1,3 @@
-
 from .base import Command
 
 from qtoggleserver.mppsolar import constants
@@ -37,12 +36,40 @@ class QPIRI(Command):
         'output_source_priority': constants.OUTPUT_SOURCE_PRIORITY_CHOICES,
         'charging_source_priority': constants.CHARGING_SOURCE_PRIORITY_CHOICES,
         'battery_max_discharging_current': constants.BATTERY_MAX_DISCHARGING_CURRENT_CHOICES,
-        'battery_back_to_charging_voltage': constants.BATTERY_BACK_TO_GRID_VOLTAGE_CHOICES_48V,
-        'battery_back_to_discharging_voltage': constants.BATTERY_BACK_TO_DISCHARGING_VOLTAGE_CHOICES_48V,
     }
 
 
-class QPIRI_GKMK(QPIRI):
+class QPIRI_GK(QPIRI):
+    RESPONSE_FMT = (
+        '{_grid_rating_voltage:f} '
+        '{_grid_rating_current:f} '
+        '{_ac_output_rating_voltage:f} '
+        '{_ac_output_rating_frequency:f} '
+        '{_ac_output_rating_current:f} '
+        '{_ac_output_rating_apparent_power:f} '
+        '{_ac_output_rating_active_power:f} '
+        '{_battery_rating_voltage:f} '
+        '{battery_back_to_charging_voltage:f} '
+        '{battery_cut_off_voltage:f} '
+        '{battery_bulk_charging_voltage:f} '
+        '{battery_float_charging_voltage:f} '
+        '{battery_type:d} '
+        '{battery_max_grid_charging_current:d} '
+        '{battery_max_charging_current:d} '
+        '{_input_voltage_range:d} '
+        '{output_source_priority:d} '
+        '{charging_source_priority:d} '
+        '{_parallel_max:d} '
+        '{_type:d} '
+        '{_topology:d} '
+        '{_output_mode:d} '
+        '{battery_back_to_discharging_voltage:f} '
+        '{_parallel_pv_ok:d} '
+        '{_parallel_pv_power_balance:d}'
+    )
+
+
+class QPIRI_MK(QPIRI):
     RESPONSE_FMT = (
         '{_grid_rating_voltage:f} '
         '{_grid_rating_current:f} '
