@@ -1,4 +1,3 @@
-
 MODE_POWER_ON = 'P'
 MODE_STANDBY = 'S'
 MODE_GRID = 'L'
@@ -72,29 +71,3 @@ BATTERY_MAX_DISCHARGING_CURRENT_CHOICES = [
     (140, '140'),
     (150, '150'),
 ]
-
-BATTERY_BACK_TO_GRID_VOLTAGE_CHOICES_48V = [
-    (44, '44'),
-    (45, '45'),
-    (46, '46'),
-    (47, '47'),
-    (48, '48'),
-    (49, '49'),
-    (50, '50'),
-    (51, '51'),
-]
-
-BATTERY_BACK_TO_DISCHARGING_VOLTAGE_CHOICES_48V = [
-    (48, '48'),
-    (49, '49'),
-    (50, '50'),
-    (51, '51'),
-    (52, '52'),
-    (53, '53'),
-    (54, '54'),
-    (55, '55'),
-    (56, '56'),
-    (57, '57'),
-    (58, '58'),
-    (0, 'Full'),
-]
