@@ -1,9 +1,8 @@
-
 import abc
 import asyncio
 import logging
 
-from typing import Dict, Optional
+from typing import Optional
 
 from qtoggleserver.lib.polled import PolledPeripheral
 
@@ -11,16 +10,13 @@ from .exceptions import MPPSolarTimeout
 from .typing import Property
 
 
-logger = logging.getLogger(__name__)
-
-
 class MPPSolarInverter(PolledPeripheral, metaclass=abc.ABCMeta):
     DEFAULT_POLL_INTERVAL = 5
     RETRY_POLL_INTERVAL = 5
 
     TIMEOUT = 10
 
-    logger = logger
+    logger = logging.getLogger(__name__)
 
     def __init__(
         self,
@@ -30,7 +26,7 @@ class MPPSolarInverter(PolledPeripheral, metaclass=abc.ABCMeta):
     ) -> None:
 
         self._model: str = model
-        self._properties: Dict[str, Property] = {}
+        self._properties: dict[str, Property] = {}
 
         super().__init__(**kwargs)
 
@@ -40,7 +36,6 @@ class MPPSolarInverter(PolledPeripheral, metaclass=abc.ABCMeta):
     async def poll(self) -> None:
         try:
             await self.read_properties()
-
         except asyncio.TimeoutError as e:
             raise MPPSolarTimeout('Timeout reading inverter status') from e
 
