@@ -1,11 +1,10 @@
-
 import asyncio
 import contextlib
 import logging
 import math
 import re
 
-from typing import Any, Dict, List, Optional, Set, Type
+from typing import Any, Optional
 
 from qtoggleserver.utils import json as json_utils
 
@@ -16,12 +15,10 @@ from .ports import BooleanPort, NumberPort, StringPort
 from .typing import Properties, Property
 
 
-logger = logging.getLogger(__name__)
-
-
 class SerialMPPSolarInverter(MPPSolarInverter):
     DEFAULT_BAUD = 2400
-    BATTERY_FORCE_WAIT = 2
+    CMD_WAIT = 0.5  # seconds
+    BATTERY_FORCE_WAIT = 5  # seconds
 
     # Filter out properties that we don't really want exposed
     BLACKLISTED_PROPERTIES = {
@@ -29,19 +26,29 @@ class SerialMPPSolarInverter(MPPSolarInverter):
         'is_configuration_status_changed',
         'is_scc_firmware_updated',
         'is_battery_voltage_too_steady_while_charging',
+        'is_battery_charging',  # is_battery_charging* properties appear to be broken
+        'is_battery_charging_from_scc',
+        'is_battery_charging_from_grid',
+        'is_battery_float_charging',
+        'is_battery_low',
+        'is_battery_present',
+        'is_grid_present',
+        'is_scc_active',
         'battery_voltage_offset_fans',
         'eeprom_version',
-        'is_dustproof_installed'
+        'is_dustproof_installed',
+        'is_turned_on',
+        'is_scc_firmware_updated',
     }
 
-    logger = logger
+    logger = logging.getLogger(__name__)
 
     def __init__(
         self,
         *,
         serial_port: str,
         serial_baud: int = DEFAULT_BAUD,
-        blacklist_properties: Optional[List[str]] = None,
+        blacklist_properties: Optional[list[str]] = None,
         force_battery_discharge_min_soc: Optional[int] = None,
         force_battery_charge_grid_min_voltage: Optional[int] = None,
         **kwargs
@@ -49,11 +56,11 @@ class SerialMPPSolarInverter(MPPSolarInverter):
 
         self._serial_port: str = serial_port
         self._serial_baud: int = serial_baud
-        self._blacklist_properties: Set[str] = set(blacklist_properties or [])
+        self._blacklist_properties: set[str] = set(blacklist_properties or [])
         self._force_battery_discharge_min_soc: Optional[int] = force_battery_discharge_min_soc
         self._force_battery_charge_min_grid_voltage: Optional[int] = force_battery_charge_grid_min_voltage
-        self._setter_command_classes_by_property: Dict[str, List[Type[commands.Command]]] = {}
-        self._choices_by_property: Dict[str, List[Dict[str, Any]]] = {}
+        self._setter_command_classes_by_property: dict[str, list[type[commands.Command]]] = {}
+        self._choices_by_property: dict[str, list[dict[str, Any]]] = {}
         self._command_lock: asyncio.Lock = asyncio.Lock()
 
         super().__init__(**kwargs)
@@ -68,7 +75,7 @@ class SerialMPPSolarInverter(MPPSolarInverter):
         else:
             return SerialIO(self._serial_port, self._serial_baud)
 
-    async def run_command(self, io: BaseIO, cls: Type[commands.Command], **params) -> Properties:
+    async def run_command(self, io: BaseIO, cls: type[commands.Command], **params) -> Properties:
         params = dict(params, **self.prepare_command_params(cls))
         if params:
             params_str = ', '.join(f'{k}={json_utils.dumps(v)}' for k, v in params.items())
@@ -83,26 +90,39 @@ class SerialMPPSolarInverter(MPPSolarInverter):
 
         request = cmd.prepare_request()
         async with self._command_lock:
+            self.debug('sending "%s"', repr(request)[2:-1])
             io.write(request)
             response = await io.read(self.TIMEOUT)
+            await asyncio.sleep(self.CMD_WAIT)
+            self.debug('received "%s"', repr(response)[2:-1])
+
         parsed_response = cmd.parse_response(response)
 
         return parsed_response
 
-    def prepare_command_params(self, cmd: Type[commands.Command]) -> Properties:
+    def prepare_command_params(self, cmd: type[commands.Command]) -> Properties:
         return cmd.REQUEST_DEFAULT_VALUES
 
     async def read_properties(self) -> None:
         with contextlib.closing(self.make_io()) as io:
             for cls in commands.get_command_classes(self._model):
                 if cls.has_response_properties():
-                    self._properties.update(await self.run_command(io, cls))
+                    try:
+                        self._properties.update(await self.run_command(io, cls))
+                    except Exception as e:
+                        self.error('command %s failed: %s', cls.get_name(), e)
+                        continue
 
     async def set_property(self, name: str, value: Property) -> None:
         cmd_classes = self._setter_command_classes_by_property[name]
         params = {name: value}
         old_value = self._properties.get(name)
 
+        if old_value == value:
+            return
+
+        self.debug('setting property "%s" from %s to %s', name, json_utils.dumps(old_value), json_utils.dumps(value))
+
         with contextlib.closing(self.make_io()) as io:
             for cls in cmd_classes:
                 await self.run_command(io, cls, **params)
@@ -161,7 +181,7 @@ class SerialMPPSolarInverter(MPPSolarInverter):
         if temp_value == battery_voltage:
             temp_value -= 1
 
-        if temp_value <= battery_back_to_discharging_voltage:
+        if temp_value >= battery_back_to_discharging_voltage:
             self.debug('adjusting battery back-to-discharging voltage not needed')
             return
 
@@ -192,7 +212,7 @@ class SerialMPPSolarInverter(MPPSolarInverter):
         if temp_value == battery_voltage:
             temp_value += 1
 
-        if temp_value >= battery_back_to_charging_voltage:
+        if temp_value <= battery_back_to_charging_voltage:
             self.debug('adjusting battery back-to-charging voltage not needed')
             return
 
@@ -202,7 +222,7 @@ class SerialMPPSolarInverter(MPPSolarInverter):
         finally:
             await self.run_command(io, cls, battery_back_to_charging_voltage=battery_back_to_charging_voltage)
 
-    async def make_port_args(self) -> List[Dict[str, Any]]:
+    async def make_port_args(self) -> list[dict[str, Any]]:
         # All available command classes for this inverter model
         cmd_classes = commands.get_command_classes(self._model)
 
@@ -236,8 +256,6 @@ class SerialMPPSolarInverter(MPPSolarInverter):
                 port_args = {
                     'property_name': name,
                     'display_name': details['display_name'],
-                    'unit': details['unit'],
-                    'choices': details['choices'] or self._choices_by_property.get(name),
                     'writable': name in self._setter_command_classes_by_property
                 }
                 if type_ == 'bool':
@@ -249,6 +267,12 @@ class SerialMPPSolarInverter(MPPSolarInverter):
                 else:
                     continue
 
+                if type_ in ('int', 'str'):
+                    port_args.update({
+                        'unit': details['unit'],
+                        'choices': details['choices'] or self._choices_by_property.get(name),
+                    })
+
                 port_args_list.append(port_args)
 
         return port_args_list
